# Kik Python API

[![PyPI Version][pypi-image]][pypi-url] [![Docs Status][docs-image]][docs-url]

This library provides tools to build bots that communicate with the Kik API.
Find out more and create your bot at [dev.kik.com][dev-kik-url].

This package can be imported using pip by adding the following to your `requirements.txt`.

```
kik==<version>
```

# Docs

Our docs are available [on readthedocs][docs-url].

## Contributing

If you're looking to contribute the the `kik` package, check out the [Contributing Guide](/CONTRIBUTING.md).

This project adheres to the Contributor Covenant [code of conduct](CODE_OF_CONDUCT.md).
By participating, you are expected to uphold this code. Please report unacceptable behavior to bots@kik.com.

## License

The kik library is released under the terms of the MIT license.
See [License](LICENSE.md) for more information or see https://opensource.org/licenses/MIT.

[dev-kik-url]: https://dev.kik.com/

[docs-image]: https://readthedocs.org/projects/kik/badge/?version=latest
[docs-url]: https://kik.readthedocs.org

[pypi-image]: https://img.shields.io/pypi/v/kik.svg
[pypi-url]: https://pypi.python.org/pypi/kik
